import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeleteIdentityProviderConfigurationRequest, DeleteIdentityProviderConfigurationResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteIdentityProviderConfigurationCommand}.
 */
export interface DeleteIdentityProviderConfigurationCommandInput extends DeleteIdentityProviderConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteIdentityProviderConfigurationCommand}.
 */
export interface DeleteIdentityProviderConfigurationCommandOutput extends DeleteIdentityProviderConfigurationResponse, __MetadataBearer {
}
declare const DeleteIdentityProviderConfigurationCommand_base: {
    new (input: DeleteIdentityProviderConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteIdentityProviderConfigurationCommandInput, DeleteIdentityProviderConfigurationCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteIdentityProviderConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteIdentityProviderConfigurationCommandInput, DeleteIdentityProviderConfigurationCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>
 *          Disables the integration between IdC and WorkMail. Authentication will continue with the directory as it was before the IdC integration. You might have to reset your directory passwords and reconfigure your desktop and mobile email clients.
 *       </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { WorkMailClient, DeleteIdentityProviderConfigurationCommand } from "@aws-sdk/client-workmail"; // ES Modules import
 * // const { WorkMailClient, DeleteIdentityProviderConfigurationCommand } = require("@aws-sdk/client-workmail"); // CommonJS import
 * const client = new WorkMailClient(config);
 * const input = { // DeleteIdentityProviderConfigurationRequest
 *   OrganizationId: "STRING_VALUE", // required
 * };
 * const command = new DeleteIdentityProviderConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteIdentityProviderConfigurationCommandInput - {@link DeleteIdentityProviderConfigurationCommandInput}
 * @returns {@link DeleteIdentityProviderConfigurationCommandOutput}
 * @see {@link DeleteIdentityProviderConfigurationCommandInput} for command's `input` shape.
 * @see {@link DeleteIdentityProviderConfigurationCommandOutput} for command's `response` shape.
 * @see {@link WorkMailClientResolvedConfig | config} for WorkMailClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>An operation received a valid organization identifier that either doesn't belong or
 *          exist in the system.</p>
 *
 * @throws {@link OrganizationStateException} (client fault)
 *  <p>The organization must have a valid state to perform certain
 *          operations on the organization or its members.</p>
 *
 * @throws {@link WorkMailServiceException}
 * <p>Base exception class for all service exceptions from WorkMail service.</p>
 *
 *
 * @public
 */
export declare class DeleteIdentityProviderConfigurationCommand extends DeleteIdentityProviderConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteIdentityProviderConfigurationRequest;
            output: {};
        };
        sdk: {
            input: DeleteIdentityProviderConfigurationCommandInput;
            output: DeleteIdentityProviderConfigurationCommandOutput;
        };
    };
}
