import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeletePersonalAccessTokenRequest, DeletePersonalAccessTokenResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeletePersonalAccessTokenCommand}.
 */
export interface DeletePersonalAccessTokenCommandInput extends DeletePersonalAccessTokenRequest {
}
/**
 * @public
 *
 * The output of {@link DeletePersonalAccessTokenCommand}.
 */
export interface DeletePersonalAccessTokenCommandOutput extends DeletePersonalAccessTokenResponse, __MetadataBearer {
}
declare const DeletePersonalAccessTokenCommand_base: {
    new (input: DeletePersonalAccessTokenCommandInput): import("@smithy/smithy-client").CommandImpl<DeletePersonalAccessTokenCommandInput, DeletePersonalAccessTokenCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeletePersonalAccessTokenCommandInput): import("@smithy/smithy-client").CommandImpl<DeletePersonalAccessTokenCommandInput, DeletePersonalAccessTokenCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>
 *          Deletes the Personal Access Token from the provided WorkMail Organization.
 *       </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { WorkMailClient, DeletePersonalAccessTokenCommand } from "@aws-sdk/client-workmail"; // ES Modules import
 * // const { WorkMailClient, DeletePersonalAccessTokenCommand } = require("@aws-sdk/client-workmail"); // CommonJS import
 * const client = new WorkMailClient(config);
 * const input = { // DeletePersonalAccessTokenRequest
 *   OrganizationId: "STRING_VALUE", // required
 *   PersonalAccessTokenId: "STRING_VALUE", // required
 * };
 * const command = new DeletePersonalAccessTokenCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeletePersonalAccessTokenCommandInput - {@link DeletePersonalAccessTokenCommandInput}
 * @returns {@link DeletePersonalAccessTokenCommandOutput}
 * @see {@link DeletePersonalAccessTokenCommandInput} for command's `input` shape.
 * @see {@link DeletePersonalAccessTokenCommandOutput} for command's `response` shape.
 * @see {@link WorkMailClientResolvedConfig | config} for WorkMailClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>An operation received a valid organization identifier that either doesn't belong or
 *          exist in the system.</p>
 *
 * @throws {@link OrganizationStateException} (client fault)
 *  <p>The organization must have a valid state to perform certain
 *          operations on the organization or its members.</p>
 *
 * @throws {@link WorkMailServiceException}
 * <p>Base exception class for all service exceptions from WorkMail service.</p>
 *
 *
 * @public
 */
export declare class DeletePersonalAccessTokenCommand extends DeletePersonalAccessTokenCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeletePersonalAccessTokenRequest;
            output: {};
        };
        sdk: {
            input: DeletePersonalAccessTokenCommandInput;
            output: DeletePersonalAccessTokenCommandOutput;
        };
    };
}
